function printout(NAME,pname,info,objp,times)
% PRINTOUT    - Print out problem and solution information.
%            Usage:  printout(NAME,pname,info,objp,times)

% Yin Zhang, January, 1995
% Department of Mathematics and Statistics
% University of Maryland  Baltimore County

global OUTFID
global message
global x y z s w
global NNZA NNZL
global Lbounds_non0
global Ubounds_exist nub
global Fixed_exist ifix infx xfix ifree
global Zrcols_exist izrcol inzcol xzrcol
global Dense_cols_exist idense ispars

converged = info(1);
iter      = info(2);
trerror   = info(3);

fprintf('\n%s',NAME);
fprintf('\n%s\n',message);
if (converged)
   fprintf('Results (unprocessed) in results.mat\n');
   fprintf('Solution xsol (processed) in solution.mat\n');
   fprintf('Primal Obj = %18.10e\n', objp);
end;
fprintf('[m n] = [%i %i], ', length(y),length(x));
fprintf('nnz(A) = %i, nnz(L) = %i\n', NNZA, NNZL);

if (Lbounds_non0)
   fprintf('Nonzero lower bounds exist.\n');
end;

if (Ubounds_exist)
   fprintf('Number of Upper bounds: %g\n',nub);
end;

if (Fixed_exist)
   fprintf('Number of fixed variables: %g\n',length(ifix));
end;

if (exist('ifree')) if (~isempty(ifree))
   fprintf('Number of free  variables: %g\n',length(ifree)/2);
end; end;

if (Zrcols_exist)
   fprintf('Number of zero columns in A: %g\n',length(izrcol));
end;

if (Dense_cols_exist)
   fprintf('Number of dense columns in A: %g\n',length(idense));
end;

fprintf('CPU seconds: %6.2f ... loading\n', times(1));
fprintf('             %6.2f ... preprocessing\n', times(2));
fprintf('             %6.2f ... solving\n', times(3));
fprintf('             %6.2f ... postprocessing\n', times(4));
fprintf('             %6.2f ... total\n\n', sum(times));

if OUTFID == [] return; end;
if OUTFID == 1  return; end;
fprintf(OUTFID, '%12s',     pname);
fprintf(OUTFID, '%4i',      converged);
fprintf(OUTFID, '%6i',      iter);
fprintf(OUTFID, '%12.2e',   trerror);
fprintf(OUTFID, '%20.10e',  objp);
fprintf(OUTFID, '%12.2f\n', sum(times(2:4)));
